/*
 * atomic.h
 *
 *  Created on: 2014/07/04
 *      Author: utsugi
 */

#ifndef PRIVATE_ATOMIC_H
#define PRIVATE_ATOMIC_H

void	atomic_add (double *data, double delta);
void	atomic_max (double *data, double val);

#endif /* PRIVATE_ATOMIC_H */
